Package org.cometd.oort
Class OortMulticastConfigurer
java.lang.Object
org.eclipse.jetty.util.component.AbstractLifeCycle
org.cometd.oort.OortMulticastConfigurer
- All Implemented Interfaces:
org.eclipse.jetty.util.component.LifeCycle
public class OortMulticastConfigurer
extends org.eclipse.jetty.util.component.AbstractLifeCycle
-
Nested Class Summary
Nested classes/interfaces inherited from class org.eclipse.jetty.util.component.AbstractLifeCycle
org.eclipse.jetty.util.component.AbstractLifeCycle.AbstractLifeCycleListener, org.eclipse.jetty.util.component.AbstractLifeCycle.StopExceptionNested classes/interfaces inherited from interface org.eclipse.jetty.util.component.LifeCycle
org.eclipse.jetty.util.component.LifeCycle.Listener -
Field Summary
Fields inherited from class org.eclipse.jetty.util.component.AbstractLifeCycle
FAILED, STARTED, STARTING, STOPPED, STOPPING -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionprotected voiddoStart()protected voiddoStop()longlongintintintbooleanjoin(long timeout)protected voidvoidsetAdvertiseInterval(long advertiseInterval)voidsetBindAddress(InetAddress bindAddress)voidsetConnectTimeout(long connectTimeout)voidsetGroupAddress(InetAddress groupAddress)voidsetGroupInterfaces(List<NetworkInterface> groupInterfaces)voidsetGroupPort(int groupPort)voidsetMaxTransmissionLength(int maxTransmissionLength)voidsetTimeToLive(int timeToLive)Methods inherited from class org.eclipse.jetty.util.component.AbstractLifeCycle
addEventListener, getEventListeners, getState, getState, isFailed, isRunning, isStarted, isStarting, isStopped, isStopping, removeEventListener, setEventListeners, start, stop, toString
-
Constructor Details
-
OortMulticastConfigurer
-
-
Method Details
-
getBindAddress
- Returns:
- the address to bind the receiver multicast socket to
-
setBindAddress
- Parameters:
bindAddress- the address to bind the receiver multicast socket to
-
getGroupAddress
- Returns:
- the multicast address onto which Oort URLs are advertised
-
setGroupAddress
- Parameters:
groupAddress- the multicast address onto which Oort URLs are advertised
-
getGroupPort
public int getGroupPort()- Returns:
- the port the receiver multicast socket listens to
-
setGroupPort
public void setGroupPort(int groupPort)- Parameters:
groupPort- the port the receiver multicast socket listens to
-
getGroupInterfaces
- Returns:
- the interfaces that receive multicast messages
-
setGroupInterfaces
- Parameters:
groupInterfaces- the interfaces that receive multicast messages
-
getTimeToLive
public int getTimeToLive()- Returns:
- the multicast time-to-live
-
setTimeToLive
public void setTimeToLive(int timeToLive)- Parameters:
timeToLive- the multicast time-to-live
-
getAdvertiseInterval
public long getAdvertiseInterval()- Returns:
- the advertisement interval in milliseconds
-
setAdvertiseInterval
public void setAdvertiseInterval(long advertiseInterval)- Parameters:
advertiseInterval- the advertisement interval in milliseconds
-
getConnectTimeout
public long getConnectTimeout()- Returns:
- the timeout to connect to another Oort node
-
setConnectTimeout
public void setConnectTimeout(long connectTimeout)- Parameters:
connectTimeout- the timeout to connect to another Oort node
-
getMaxTransmissionLength
public int getMaxTransmissionLength()- Returns:
- the max Oort URL length (must be smaller than the max transmission unit)
-
setMaxTransmissionLength
public void setMaxTransmissionLength(int maxTransmissionLength)- Parameters:
maxTransmissionLength- the max Oort URL length (must be smaller than the max transmission unit)
-
doStart
- Overrides:
doStartin classorg.eclipse.jetty.util.component.AbstractLifeCycle- Throws:
Exception
-
doStop
- Overrides:
doStopin classorg.eclipse.jetty.util.component.AbstractLifeCycle- Throws:
Exception
-
join
public boolean join(long timeout) -
receive
-