Uses of Class
org.cometd.oort.OortObject.Info
Packages that use OortObject.Info
-
Uses of OortObject.Info in org.cometd.oort
Methods in org.cometd.oort that return OortObject.InfoModifier and TypeMethodDescriptionOortObject.getInfoByObject(T object)protected OortObject.Info<T>Methods in org.cometd.oort that return types with arguments of type OortObject.InfoModifier and TypeMethodDescriptionprotected Collection<OortObject.Info<T>>OortObject.getInfos()OortObject.iterator()Methods in org.cometd.oort with parameters of type OortObject.InfoModifier and TypeMethodDescriptionprotected voidOortObject.notifyRemoved(OortObject.Info<T> info)protected voidOortObject.notifyUpdated(OortObject.Info<T> oldInfo, OortObject.Info<T> newInfo)default voidCallback method invoked when elements are added to the entity list.protected abstract voidprotected voidprotected voidOortMap.onItem(OortObject.Info<ConcurrentMap<K,V>> info, Map<String,Object> data)default voidOortMap.EntryListener.onPut(OortObject.Info<ConcurrentMap<K,V>> info, OortMap.Entry<K,V> entry)Callback method invoked after an entry is put into the entity map.voidOortList.DeltaListener.onRemoved(OortObject.Info<List<E>> info)default voidCallback method invoked when elements are removed from the entity list.voidOortMap.DeltaListener.onRemoved(OortObject.Info<ConcurrentMap<K,V>> info)default voidOortMap.EntryListener.onRemoved(OortObject.Info<ConcurrentMap<K,V>> info, OortMap.Entry<K,V> entry)Callback method invoked after an entry is removed from the entity map.default voidOortObject.Listener.onRemoved(OortObject.Info<T> info)Callback method invoked when the object value is removed, for example because the correspondent node has been shut down or crashed.voidOortList.DeltaListener.onUpdated(OortObject.Info<List<E>> oldInfo, OortObject.Info<List<E>> newInfo)voidOortMap.DeltaListener.onUpdated(OortObject.Info<ConcurrentMap<K,V>> oldInfo, OortObject.Info<ConcurrentMap<K,V>> newInfo)default voidOortObject.Listener.onUpdated(OortObject.Info<T> oldInfo, OortObject.Info<T> newInfo)Callback method invoked when the object value is updated.Method parameters in org.cometd.oort with type arguments of type OortObject.InfoModifier and TypeMethodDescriptionOortObject.Merger.merge(Collection<OortObject.Info<T>> infos)Merges the givenOortObject.Infos.OortObjectMergers.ListUnionMerger.merge(Collection<OortObject.Info<List<E>>> infos)