Uses of Class
org.cometd.oort.OortPrimaryService
| Package | Description |
|---|---|
| org.cometd.oort |
-
Uses of OortPrimaryService in org.cometd.oort
Subclasses of OortPrimaryService in org.cometd.oort Modifier and Type Class Description classOortMasterLongDeprecated.useOortPrimaryLonginsteadclassOortMasterService<R,C>Deprecated.useOortPrimaryServiceinstead.classOortPrimaryLongA distributed counter service to be deployed on a Oort cluster that modifies alongvalue hosted in a "primary" node.