Package org.cometd.oort
package org.cometd.oort
-
Interface SummaryInterfaceDescriptionListener interface that gets notified of comet events, that is when a new comet joins the cloud or when a comet leaves the cloud.Listener for element events that update the entity list, either locally or remotely.OortMap.EntryListener<K,V>Listener for entry events that update the entity map, either locally or remotely.Factory that creates objects stored by
OortObjects.Listener for events that update the value of aOortObject.Info, either local or remote.OortObject.Merger<T,R>A merge strategy for object values.An asynchronous result.Callback invoked when the result of the operation on the counter is available, or when the operation failed.The representation of where a user is.Listener interface that gets notified of remote Seti presence events. -
Class SummaryClassDescriptionOort is the cluster manager that links one CometD server to a set of other CometD servers.Comet event object delivered to
Oort.CometListenermethods.The Oort comet client connects a local Oort comet server to a remote Oort comet server.This servlet serves as a base class for initializing and configuring an instance of theOortCometD cluster manager.OortList<E>A specialized oort object whose entity is aList.An implementation ofOortObject.Listenerthat converts whole list events intoOortList.ElementListenerevents.A shared atomic long made of an internalAtomicLongand of an internalOortObject<Long>.OortLongMap<V>The equivalent of anOortMap<Long,V>.OortMap<K,V>A specialized oort object whose entity is aConcurrentMap.OortMap.DeltaListener<K,V>An implementation ofOortObject.Listenerthat converts whole map events intoOortMap.EntryListenerevents.OortMap.Entry<K,V>A triple that holds the key, the previous value and the new value, used to notify entry updates:This servlet initializes and configures an instance of theOortCometD cluster manager via autodiscovery of other Oort comets using UDP multicast.OortObject<T>AnOortObjectrepresents a named composite entity that is distributed in an Oort cluster.The oort object part holding the object and the metadata associated with it.Implementation ofOortObject.Resultthat allows applications to block, waiting for the result, viaOortObject.Result.Deferred.get(long, TimeUnit).A distributed counter service to be deployed on a Oort cluster that modifies alongvalue hosted in a "primary" node.OortPrimaryService<R,C>OortPrimaryServiceextendsOortServiceto allow applications to perform actions on entities that always live in a "primary" node.OortService<R,C>AnOortServiceallows applications to forward actions to Oort nodes that own the entity onto which the action should be applied.Encapsulates a forwarded request.Encapsulates the result of a forwarded request returned byOortService.onForward(Request).Utility context that stores theServerSessionand theServerMessage.This servlet initializes and configures an instance of theOortCometD cluster manager with a static list of other Oort comet URLs.The equivalent of anOortMap<String,V>.The component that Searches for Extra Terrestrial Intelligence or, in this case, just searches for a user logged onto a comet in an Oort cloud.Seti presence event object, delivered toSeti.PresenceListenermethods.This servlet initializes and configures and instance of theSetiuser mapper.